% This function appends compartment name to state variables in the equations
% It also ignores comments
%

% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

function [Equations_out] = appendCompName(Equations_in,comp_name,ReactantNames,kName);   

delimiters = '.<>!@''\//*+-%$#@&^()[]{}|`~;= ';

% Append compartment name to state variables in equations
N = length(ReactantNames);
ReactantNames{N+1} = 'h';
ReactantNames{N+2} = 'm';
ReactantNames{N+3} = 'k';

Equations_out = [];

b = 1;
% For every equation
while b <= length( Equations_in )
    Equations_out{b} = '';
    % Loop until there is no text left in the input field
    while( length( Equations_in{b} ) > 0 )
    
        % Loop until a word that is not a delimiter is found
        % of course, check whether there is even text in the input
        % and whether we haven't run past the end of the line
        a = 1;              
        if isempty( Equations_in{b} )
            break;
        else
            while( a < length( Equations_in{b} ) + 1 )
                if ~ismember( Equations_in{b}(a), delimiters )
                    break;
                end
                a = a + 1;
            end
        end
        
        % if we skipped past delimiters copy them to the output
        if ( a - 1 ) > 0            
            Equations_out{b} = [ Equations_out{b} Equations_in{b}(1 : a - 1 ) ];
        end

        % Grab a word from the list, and remove it from the list of things
        % to do. Basically the 'used' input gets chopped from the start.
        [ token Equations_in{b} ] = strtok(Equations_in{b}, delimiters );
        
        % If the token starts with P_ Kh_ Kk_ or Km_ it needs to be removed
        ntoken = token; % <-- bugfix september 15
        if length( token ) > 2
            if strcmp( token( 1 : 2 ), 'P_' )
                ntoken = token( 3 : length( token ) );
            end
            if length( token ) > 3
                for a = 1 : length( kName )
                    if max( strcmp( token( 1 : 3 ), strcat('K', kName, '_') ) )
                        ntoken = token( 4 : length( token ) );
                    end
                end
            end
        end
        
        % If the token is a reactant add the name, otherwise, don't
        if ismember( ntoken, ReactantNames )
            token = [ token '_' comp_name ];
        end
        
        % if the token represents a volume, add the appropriate volume name
%         if token == 'V'   %FW: commented by FW
%             token = [ token '_' comp_name ];
%         end
        if strcmp(token,'VWater') || strcmp(token,'VRegion')   %FW: added by FW to explicitly account for water content and regional volume 
            token = [ token '_' comp_name ];
        elseif strcmp(token,'V') %FW: added by FW to be compatible with previous default definition of 'V'
            token = [ token 'Water_' comp_name];
        end
    
        Equations_out{b} = [ Equations_out{b} token ];
    end
    b = b + 1;    
end