% This function writes the current parameterset to a human readable file
%
% function generateParameterSet( filename, param, modelInfo, parx0, overwriteFlag )
%
% Mandatory parameters:
%   filename      - Name for the m file to be generated (without .m!)
%   param         - The parameter vector to generate from
%   modelInfo     - modelInfo structure
%   parx0         - Specify 0 to write parameters, 1 to write initial conds
%
% Optional parameters:
%   overwriteFlag - Specify 1 here to automatically overwrite files
%                   if they already exist.

function generateParameterSet( filename, param, modelInfo, parx0, overwriteFlag )
% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

try
    filename;
    param;
    modelInfo;
    parx0;
catch
    help generateParameterSet
    return;
end

try
    modelInfo.ParID;
    modelInfo.SVarID;
catch
    disp( 'Error, invalid model info structure' );
    return;
end

fn = strcat( filename, '.m' );
if exist( fn ) > 1
    disp( 'Warning! File already exists.' );
    try
        if overwriteFlag == 0
            return;
        end
    catch
        return;
    end
    disp( 'Overwriting...' )
end

fid = fopen( fn, 'w' );
fprintf( fid, '%s', BISENlogo(3) );
if parx0 == 0
    fprintf( fid, '%%\r\n%% Automatically generated parameter file\r\n' );
    fprintf( fid, '%% Usage: param = %s( modelInfo )\r\n\r\n', filename );
    fprintf( fid, 'function param = %s( modelInfo )\r\n', filename );    
else 
    fprintf( fid, '%%\r\n%% Automatically generated initial condition file\r\n' );
    fprintf( fid, '%% Usage: param = %s( modelInfo )\r\n\r\n', filename );
    fprintf( fid, 'function param = %s( modelInfo )\r\n', filename );        
end
fprintf( fid, '  param = [];\r\n' );
if parx0 == 0
    t = fieldnames( modelInfo.ParID );
    for a = 1 : length( t )
        fprintf( fid, ...
            '  param = setParameter( param, modelInfo.ParID, ''%s'', %d );\r\n', ...
            t{a}, param( getfield( modelInfo.ParID, t{a} ) ) );
    end
end
if parx0 == 1
    t = fieldnames( modelInfo.SVarID );  
    for a = 1 : length( t )
        fprintf( fid, ...
            '  param = setParameter( param, modelInfo.SVarID, ''%s'', %d );\r\n', ...
            t{a}, param( getfield( modelInfo.SVarID, t{a} ) ) );
    end
end
fclose( fid );