% function vector = setParameter( vector, field, value )
%
% function to safely set parameters using names
% from the ID structures. When a field is not found
% an error is returned, but the execution is not halted.
%
% Mandatory Input:
%       vector        -  vector to manipulate
%       ID structure  -  structure containing the indices
%       fieldname     -  field containing the index
%       value         -  value to set the parameter to
%
% Output:
%       vector        -  the vector with (if successful) the parameter
%                        changed
function vector = setParameter( vector, IDstruct, fieldname, value )
% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

try
    vector( getfield( IDstruct, fieldname ) ) = value;
catch
    disp( sprintf( 'Field name %s not found!', fieldname ) );
end
