% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

clear all;

%% Setting paths
path(path,'..\Warnings');
path(path,'..\BiochemicalReactions');
path(path,'..\Transporters');
path(path,'..\Databases');
path(path,'..\BuilderFiles');
path(path,'..\ExperimentalData');
path(path,'..\Examples');

%% Building model:
ModelInfo = BuildDXDT('Example1.bsl','dXdT.m');

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = 0.1;   % k (kinetic constant for ATP hydrolysis)
T = 25;         % Temperature
% (2.) Setting initial values
xo(1) = 10e-3;  % [ATP] (M)
xo(2) = 0;      % [ADP] (M)
xo(3) = 0;      % [Pi] (M)
xo(4) = 1e-7;   % [H] (M)
xo(5) = 1e-3;   % [Mg] (M)
xo(6) = 150e-3; % [K] (M)
% (3.) Running for 15-second time course
[t,x] = ode45(@dXdT,[0 15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,2)*1e3,'k-',t,x(:,5)*1e3,'k-');
set(p,'linewidth',1.5);
text(2,9,'[ATP]','Fontsize',14);
text(2,3.5,'[ADP]','Fontsize',14);
text(5,1.9,'[Mg^{2+}]','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); plot(t,-log10(x(:,4)),'k-','linewidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
%%
