% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.

clear all;

%% Setting paths
path(path,'..\Warnings');
path(path,'..\BiochemicalReactions');
path(path,'..\Transporters');
path(path,'..\Databases');
path(path,'..\BuilderFiles');
path(path,'..\ExperimentalData');
path(path,'..\Examples');

%% Building model:
ModelInfo = BuildDXDT('Example2.bsl','dXdT.m');

%% Simulating Example 2
% (1.) Setting parameter values (no buffering)
B_X(1:3)  = 1;      % Buffer capacity in both compartments
K_BX(1:3) = 1e-7;   % Buffer dissoc. constant in both compartments
T = 25;             % Temperature

% Enzyme and transporter activities:
par(1) = 0.01;      % k_ATPase (cytoplasm)
par(2) = 100.0;     % k_CK (cytoplasm)
par(3) = 1e-4;      % k_ANT
par(4) = 1e-3;      % F1F0 ATPase
par(5) = 1e-5;      % membrane capacitance
% (2.) Setting initial values
xo(1)  = 10e-3;     % ATP_cytoplasm
xo(2)  = 0;         % ADP_cytoplasm
xo(3)  = 0;         % Pi_cytoplasm
xo(4)  = 10e-3;     % phosphocreatine_cytoplasm
xo(5)  = 10e-3;     % creatine_cytoplasm
xo(6)  = 0;         % ATP_matrix
xo(7)  = 10e-3;     % ADP_matrix
xo(8)  = 5e-3;      % Pi_matrix
xo(9)  = 1e-7;      % h_cytoplasm
xo(10) = 1e-3;      % m_cytoplasm
xo(11) = 100e-3;    % k_cytoplasm
xo(12) = 1e-7;      % h_matrix
xo(13) = 1e-3;      % m_matrix
xo(14) = 100e-3;    % k_matrix
xo(15) = 0;         % DPsi_cytoplasm_to_matrix

% (3.) Running for 15-second time course
[t,x] = ode23s(@dXdT,[0 120],xo,[],T,B_X,K_BX,par);

% (4.) Plotting results
figure(1); p = plot(t,x(:,15),'k-');
set(p,'linewidth',1.5);
ylabel('\Delta\Psi (mV)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,1)*1e3,'k-',t,x(:,2)*1e3,'k-');
set(p,'linewidth',1.5);
text(5,9,'[ATP]_{cytoplasm}','Fontsize',14);
text(5,0.9,'[ADP]_{cytoplasm}','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,x(:,6)*1e3,'k-',t,x(:,7)*1e3,'k-');
set(p,'linewidth',1.5);
text(20,2.1,'[ATP]_{matrix}','Fontsize',14);
text(20,7.7,'[ADP]_{matrix}','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

%%
