% function [f,J,] = dXdT(t,x,T,BX,K_BX,par)
%
%
%
% Output parameters:
%   f     time derivatives of the model
%   J     flux
%
%
% Mandatory input parameters:
%   t     time
%   x     state variables at t=0
%   T     temperature in degreesCelcius
%   BX    buffer sizes
%   K_BX  proton buffer dissociation constants ( matrix cytoplasm im )
%   par   parameter vector for the free parameters
%   
%
% State Variables:
% [pyruvate_matrix , COAS_matrix , NAD_matrix , CO2tot_matrix , acetylcoA_matrix , NADH_matrix , oxaloacetate_matrix , citrate_matrix , ATP_matrix , ADP_matrix , AMP_matrix , succinylcoA_matrix , isocitrate_matrix , ketoglutarate_matrix , GDP_matrix , Pi_matrix , succinate_matrix , GTP_matrix , coQ_matrix , coQH2_matrix , fumarate_matrix , malate_matrix , aspartate_matrix , glutamate_matrix , glucose_cytoplasm , ATP_cytoplasm , ADP_cytoplasm , glucose6phos_cytoplasm , pyruvate_im , glutamate_im , citrate_im , malate_im , ketoglutarate_im , Pi_im , succinate_im , aspartate_im , cytocox_im , cytocred_im , O2aq_matrix , ADP_im , ATP_im , pyruvate_cytoplasm , citrate_cytoplasm , malate_cytoplasm , ketoglutarate_cytoplasm , succinate_cytoplasm , glutamate_cytoplasm , aspartate_cytoplasm , fumarate_cytoplasm , fumarate_im , isocitrate_cytoplasm , isocitrate_im , AMP_cytoplasm , AMP_im , Pi_cytoplasm ]
%
%
% Free Parameters:
% [Vmf_PDH , Vmf_CTS , Vmf_ACON , Vmf_IDH , Vmf_AKGDH , Kir1 , Vmf_SCS , Vmf_SDH , Vmf_FUM , Vmf_MDH , Vmf_NDK , Vmf_GOT , x_HK , k1_F1F0 , x_PYRH , x_GLUH , x_CITMAL , x_AKGMAL , x_MALPI , x_SUCMAL , x_ASPGLU , ETC1Activity , ETC3_activity , k_Pi1 , k_Pi2 , ETC4_activity , x_PIH , k_PIH , k1_KH , x_ANT , x_HLE , x_PYRPERM , x_CITPERM , x_MALPERM , x_AKGPERM , x_SUCPERM , x_GLUPERM , x_ASPPERM , x_FUMPERM , x_ICITPERM , x_ADPPERM , x_ATPPERM , x_AMPPERM , x_PIPERM ]

function [f,J,varargout] = dXdT(t,x,T,BX,K_BX,par)
%% GLOBAL VARIABLES
% temperature 37

% Global experimental values

	% mito membrane area per cell volume micron^{-1};

	gamma  = 5.99;


    	% minimal parameter value
	MinCon = 0;


%% LIST OF STATE VARIABLES
% 1 pyruvate_matrix
% 2 COAS_matrix
% 3 NAD_matrix
% 4 CO2tot_matrix
% 5 acetylcoA_matrix
% 6 NADH_matrix
% 7 oxaloacetate_matrix
% 8 citrate_matrix
% 9 ATP_matrix
% 10 ADP_matrix
% 11 AMP_matrix
% 12 succinylcoA_matrix
% 13 isocitrate_matrix
% 14 ketoglutarate_matrix
% 15 GDP_matrix
% 16 Pi_matrix
% 17 succinate_matrix
% 18 GTP_matrix
% 19 coQ_matrix
% 20 coQH2_matrix
% 21 fumarate_matrix
% 22 malate_matrix
% 23 aspartate_matrix
% 24 glutamate_matrix
% 25 glucose_cytoplasm
% 26 ATP_cytoplasm
% 27 ADP_cytoplasm
% 28 glucose6phos_cytoplasm
% 29 pyruvate_im
% 30 glutamate_im
% 31 citrate_im
% 32 malate_im
% 33 ketoglutarate_im
% 34 Pi_im
% 35 succinate_im
% 36 aspartate_im
% 37 cytocox_im
% 38 cytocred_im
% 39 O2aq_matrix
% 40 ADP_im
% 41 ATP_im
% 42 pyruvate_cytoplasm
% 43 citrate_cytoplasm
% 44 malate_cytoplasm
% 45 ketoglutarate_cytoplasm
% 46 succinate_cytoplasm
% 47 glutamate_cytoplasm
% 48 aspartate_cytoplasm
% 49 fumarate_cytoplasm
% 50 fumarate_im
% 51 isocitrate_cytoplasm
% 52 isocitrate_im
% 53 AMP_cytoplasm
% 54 AMP_im
% 55 Pi_cytoplasm
% 56 h_matrix
% 57 m_matrix
% 58 k_matrix
% 59 h_cytoplasm
% 60 m_cytoplasm
% 61 k_cytoplasm
% 62 h_cytoplasm = h_im
% 63 m_cytoplasm = m_im
% 64 k_cytoplasm = k_im
% 65 DPsi_im_to_matrix
% 66 DPsi_cytoplasm_to_im

% PARTIAL VOLUME FRACTIONS
VWater_matrix = 0.6514; % [=] l water (l region)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 
VRegion_matrix = 0.00124844; % [=] l region (l tissue)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 
VWater_cytoplasm = 1; % [=] l water (l region)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 
VRegion_cytoplasm = 0.998752; % [=] l region (l tissue)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 
VWater_im = 0.0724; % [=] l water (l region)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 
VRegion_im = 0.00124844; % [=] l region (l tissue)^{-1}, Vinnakota and Bassingthwaighte, AJP, 2004 

%% THERMODYNAMIC DATA
RT = 8.314*(T+273.15)/1e3; % kJ  mol^{-1}
F = 0.096484; % kJ mol^{-1} mV^{-1}

%% STATE VARIABLES

% Concentrations of Reference Species
pyruvate_matrix = x(1);
COAS_matrix = x(2);
NAD_matrix = x(3);
CO2tot_matrix = x(4);
acetylcoA_matrix = x(5);
NADH_matrix = x(6);
oxaloacetate_matrix = x(7);
citrate_matrix = x(8);
ATP_matrix = x(9);
ADP_matrix = x(10);
AMP_matrix = x(11);
succinylcoA_matrix = x(12);
isocitrate_matrix = x(13);
ketoglutarate_matrix = x(14);
GDP_matrix = x(15);
Pi_matrix = x(16);
succinate_matrix = x(17);
GTP_matrix = x(18);
coQ_matrix = x(19);
coQH2_matrix = x(20);
fumarate_matrix = x(21);
malate_matrix = x(22);
aspartate_matrix = x(23);
glutamate_matrix = x(24);
glucose_cytoplasm = x(25);
ATP_cytoplasm = x(26);
ADP_cytoplasm = x(27);
glucose6phos_cytoplasm = x(28);
pyruvate_im = x(29);
glutamate_im = x(30);
citrate_im = x(31);
malate_im = x(32);
ketoglutarate_im = x(33);
Pi_im = x(34);
succinate_im = x(35);
aspartate_im = x(36);
cytocox_im = x(37);
cytocred_im = x(38);
O2aq_matrix = x(39);
ADP_im = x(40);
ATP_im = x(41);
pyruvate_cytoplasm = x(42);
citrate_cytoplasm = x(43);
malate_cytoplasm = x(44);
ketoglutarate_cytoplasm = x(45);
succinate_cytoplasm = x(46);
glutamate_cytoplasm = x(47);
aspartate_cytoplasm = x(48);
fumarate_cytoplasm = x(49);
fumarate_im = x(50);
isocitrate_cytoplasm = x(51);
isocitrate_im = x(52);
AMP_cytoplasm = x(53);
AMP_im = x(54);
Pi_cytoplasm = x(55);
% Concentrations of H, Mg, and K
h_matrix = x(56);
m_matrix = x(57);
k_matrix = x(58);
h_cytoplasm = x(59);
m_cytoplasm = x(60);
k_cytoplasm = x(61);
h_im = x(59); % Permeation
m_im = x(60); % Permeation
k_im = x(61); % Permeation

% Membrane potentials
DPsi_im_to_matrix = x(65);
DPsi_cytoplasm_to_im = x(66);

%% DISSOCIATION CONSTANTS
% pyruvate_matrix
Kh(1) = 0.004342603252078945;
Km(1) = 0.09553750450747911;
Kk(1) = 0.11969801449130479;
% COAS_matrix
Kh(2) = 7.5872945883630875e-009;
Km(2) = Inf;
Kk(2) = Inf;
% NAD_matrix
Kh(3) = Inf;
Km(3) = Inf;
Kk(3) = Inf;
% CO2tot_matrix
Kh(4) = 1.514167405186268e-010;
Km(4) = Inf;
Kk(4) = Inf;
% acetylcoA_matrix
Kh(5) = Inf;
Km(5) = Inf;
Kk(5) = Inf;
% NADH_matrix
Kh(6) = Inf;
Km(6) = Inf;
Kk(6) = Inf;
% oxaloacetate_matrix
Kh(7) = 0.00015141674051862664;
Km(7) = 0.13814901290517506;
Kk(7) = Inf;
% citrate_matrix
Kh(8) = 2.7546665205956405e-006;
Km(8) = 0.00048047139882426425;
Kk(8) = 0.33133006036859936;
% ATP_matrix
Kh(9) = 2.7566016511811682e-007;
Km(9) = 8.4303632255990519e-005;
Kk(9) = 0.09708512798373839;
% ADP_matrix
Kh(10) = 4.1057373286278706e-007;
Km(10) = 0.00071485288102034542;
Kk(10) = 0.1319048728526625;
% AMP_matrix
Kh(11) = 6.2176978692908864e-007;
Km(11) = 0.019462203648493423;
Kk(11) = 0.23997936127262226;
% succinylcoA_matrix
Kh(12) = 0.00010966977350385349;
Km(12) = Inf;
Kk(12) = Inf;
% isocitrate_matrix
Kh(13) = 2.2660048738054451e-006;
Km(13) = 0.0041259283254227218;
Kk(13) = Inf;
% ketoglutarate_matrix
Kh(14) = Inf;
Km(14) = Inf;
Kk(14) = Inf;
% GDP_matrix
Kh(15) = 5.014883398159419e-007;
Km(15) = 0.0028217704376049622;
Kk(15) = 0.038927887780503413;
% Pi_matrix
Kh(16) = 2.3075318323898138e-007;
Km(16) = 0.028149416570991275;
Kk(16) = 0.38034165601214515;
% succinate_matrix
Kh(17) = 6.4527518893172347e-006;
Km(17) = 0.063877481692394447;
Kk(17) = 0.42863973618362095;
% GTP_matrix
Kh(18) = 3.7183287636242726e-007;
Km(18) = 0.00031673464679257576;
Kk(18) = 0.019514066748113314;
% coQ_matrix
Kh(19) = Inf;
Km(19) = Inf;
Kk(19) = Inf;
% coQH2_matrix
Kh(20) = Inf;
Km(20) = Inf;
Kk(20) = Inf;
% fumarate_matrix
Kh(21) = 9.7762858862494379e-005;
Km(21) = Inf;
Kk(21) = Inf;
% malate_matrix
Kh(22) = 2.3069280947427119e-005;
Km(22) = 0.025828472176434858;
Kk(22) = 0.79464635030879283;
% aspartate_matrix
Kh(23) = 0.00023023155676210814;
Km(23) = Inf;
Kk(23) = Inf;
% glutamate_matrix
Kh(24) = 8.1530280646559256e-005;
Km(24) = Inf;
Kk(24) = Inf;
% glucose_cytoplasm
Kh(25) = Inf;
Km(25) = Inf;
Kk(25) = Inf;
% ATP_cytoplasm
Kh(26) = 2.7566016511811682e-007;
Km(26) = 8.4303632255990519e-005;
Kk(26) = 0.09708512798373839;
% ADP_cytoplasm
Kh(27) = 4.1057373286278706e-007;
Km(27) = 0.00071485288102034542;
Kk(27) = 0.1319048728526625;
% glucose6phos_cytoplasm
Kh(28) = 9.3362805401942073e-007;
Km(28) = Inf;
Kk(28) = Inf;
% pyruvate_im
Kh(29) = 0.004342603252078945;
Km(29) = 0.09553750450747911;
Kk(29) = 0.11969801449130479;
% glutamate_im
Kh(30) = 8.1530280646559256e-005;
Km(30) = Inf;
Kk(30) = Inf;
% citrate_im
Kh(31) = 2.7546665205956405e-006;
Km(31) = 0.00048047139882426425;
Kk(31) = 0.33133006036859936;
% malate_im
Kh(32) = 2.3069280947427119e-005;
Km(32) = 0.025828472176434858;
Kk(32) = 0.79464635030879283;
% ketoglutarate_im
Kh(33) = Inf;
Km(33) = Inf;
Kk(33) = Inf;
% Pi_im
Kh(34) = 2.3075318323898138e-007;
Km(34) = 0.028149416570991275;
Kk(34) = 0.38034165601214515;
% succinate_im
Kh(35) = 6.4527518893172347e-006;
Km(35) = 0.063877481692394447;
Kk(35) = 0.42863973618362095;
% aspartate_im
Kh(36) = 0.00023023155676210814;
Km(36) = Inf;
Kk(36) = Inf;
% cytocox_im
Kh(37) = Inf;
Km(37) = Inf;
Kk(37) = Inf;
% cytocred_im
Kh(38) = Inf;
Km(38) = Inf;
Kk(38) = Inf;
% O2aq_matrix
Kh(39) = Inf;
Km(39) = Inf;
Kk(39) = Inf;
% ADP_im
Kh(40) = 4.1057373286278706e-007;
Km(40) = 0.00071485288102034542;
Kk(40) = 0.1319048728526625;
% ATP_im
Kh(41) = 2.7566016511811682e-007;
Km(41) = 8.4303632255990519e-005;
Kk(41) = 0.09708512798373839;
% pyruvate_cytoplasm
Kh(42) = 0.004342603252078945;
Km(42) = 0.09553750450747911;
Kk(42) = 0.11969801449130479;
% citrate_cytoplasm
Kh(43) = 2.7546665205956405e-006;
Km(43) = 0.00048047139882426425;
Kk(43) = 0.33133006036859936;
% malate_cytoplasm
Kh(44) = 2.3069280947427119e-005;
Km(44) = 0.025828472176434858;
Kk(44) = 0.79464635030879283;
% ketoglutarate_cytoplasm
Kh(45) = Inf;
Km(45) = Inf;
Kk(45) = Inf;
% succinate_cytoplasm
Kh(46) = 6.4527518893172347e-006;
Km(46) = 0.063877481692394447;
Kk(46) = 0.42863973618362095;
% glutamate_cytoplasm
Kh(47) = 8.1530280646559256e-005;
Km(47) = Inf;
Kk(47) = Inf;
% aspartate_cytoplasm
Kh(48) = 0.00023023155676210814;
Km(48) = Inf;
Kk(48) = Inf;
% fumarate_cytoplasm
Kh(49) = 9.7762858862494379e-005;
Km(49) = Inf;
Kk(49) = Inf;
% fumarate_im
Kh(50) = 9.7762858862494379e-005;
Km(50) = Inf;
Kk(50) = Inf;
% isocitrate_cytoplasm
Kh(51) = 2.2660048738054451e-006;
Km(51) = 0.0041259283254227218;
Kk(51) = Inf;
% isocitrate_im
Kh(52) = 2.2660048738054451e-006;
Km(52) = 0.0041259283254227218;
Kk(52) = Inf;
% AMP_cytoplasm
Kh(53) = 6.2176978692908864e-007;
Km(53) = 0.019462203648493423;
Kk(53) = 0.23997936127262226;
% AMP_im
Kh(54) = 6.2176978692908864e-007;
Km(54) = 0.019462203648493423;
Kk(54) = 0.23997936127262226;
% Pi_cytoplasm
Kh(55) = 2.3075318323898138e-007;
Km(55) = 0.028149416570991275;
Kk(55) = 0.38034165601214515;

%% BINDING POLYNOMIALS
P( 1 ) = 1  + h_matrix/Kh(1) + m_matrix/Km(1) + k_matrix/Kk(1);
P( 2 ) = 1  + h_matrix/Kh(2) + m_matrix/Km(2) + k_matrix/Kk(2);
P( 3 ) = 1  + h_matrix/Kh(3) + m_matrix/Km(3) + k_matrix/Kk(3);
P( 4 ) = 1  + h_matrix/Kh(4) + m_matrix/Km(4) + k_matrix/Kk(4);
P( 5 ) = 1  + h_matrix/Kh(5) + m_matrix/Km(5) + k_matrix/Kk(5);
P( 6 ) = 1  + h_matrix/Kh(6) + m_matrix/Km(6) + k_matrix/Kk(6);
P( 7 ) = 1  + h_matrix/Kh(7) + m_matrix/Km(7) + k_matrix/Kk(7);
P( 8 ) = 1  + h_matrix/Kh(8) + m_matrix/Km(8) + k_matrix/Kk(8);
P( 9 ) = 1  + h_matrix/Kh(9) + m_matrix/Km(9) + k_matrix/Kk(9);
P( 10 ) = 1  + h_matrix/Kh(10) + m_matrix/Km(10) + k_matrix/Kk(10);
P( 11 ) = 1  + h_matrix/Kh(11) + m_matrix/Km(11) + k_matrix/Kk(11);
P( 12 ) = 1  + h_matrix/Kh(12) + m_matrix/Km(12) + k_matrix/Kk(12);
P( 13 ) = 1  + h_matrix/Kh(13) + m_matrix/Km(13) + k_matrix/Kk(13);
P( 14 ) = 1  + h_matrix/Kh(14) + m_matrix/Km(14) + k_matrix/Kk(14);
P( 15 ) = 1  + h_matrix/Kh(15) + m_matrix/Km(15) + k_matrix/Kk(15);
P( 16 ) = 1  + h_matrix/Kh(16) + m_matrix/Km(16) + k_matrix/Kk(16);
P( 17 ) = 1  + h_matrix/Kh(17) + m_matrix/Km(17) + k_matrix/Kk(17);
P( 18 ) = 1  + h_matrix/Kh(18) + m_matrix/Km(18) + k_matrix/Kk(18);
P( 19 ) = 1  + h_matrix/Kh(19) + m_matrix/Km(19) + k_matrix/Kk(19);
P( 20 ) = 1  + h_matrix/Kh(20) + m_matrix/Km(20) + k_matrix/Kk(20);
P( 21 ) = 1  + h_matrix/Kh(21) + m_matrix/Km(21) + k_matrix/Kk(21);
P( 22 ) = 1  + h_matrix/Kh(22) + m_matrix/Km(22) + k_matrix/Kk(22);
P( 23 ) = 1  + h_matrix/Kh(23) + m_matrix/Km(23) + k_matrix/Kk(23);
P( 24 ) = 1  + h_matrix/Kh(24) + m_matrix/Km(24) + k_matrix/Kk(24);
P( 39 ) = 1  + h_matrix/Kh(39) + m_matrix/Km(39) + k_matrix/Kk(39);
P( 25 ) = 1  + h_cytoplasm/Kh(25) + m_cytoplasm/Km(25) + k_cytoplasm/Kk(25);
P( 26 ) = 1  + h_cytoplasm/Kh(26) + m_cytoplasm/Km(26) + k_cytoplasm/Kk(26);
P( 27 ) = 1  + h_cytoplasm/Kh(27) + m_cytoplasm/Km(27) + k_cytoplasm/Kk(27);
P( 28 ) = 1  + h_cytoplasm/Kh(28) + m_cytoplasm/Km(28) + k_cytoplasm/Kk(28);
P( 42 ) = 1  + h_cytoplasm/Kh(42) + m_cytoplasm/Km(42) + k_cytoplasm/Kk(42);
P( 43 ) = 1  + h_cytoplasm/Kh(43) + m_cytoplasm/Km(43) + k_cytoplasm/Kk(43);
P( 44 ) = 1  + h_cytoplasm/Kh(44) + m_cytoplasm/Km(44) + k_cytoplasm/Kk(44);
P( 45 ) = 1  + h_cytoplasm/Kh(45) + m_cytoplasm/Km(45) + k_cytoplasm/Kk(45);
P( 46 ) = 1  + h_cytoplasm/Kh(46) + m_cytoplasm/Km(46) + k_cytoplasm/Kk(46);
P( 47 ) = 1  + h_cytoplasm/Kh(47) + m_cytoplasm/Km(47) + k_cytoplasm/Kk(47);
P( 48 ) = 1  + h_cytoplasm/Kh(48) + m_cytoplasm/Km(48) + k_cytoplasm/Kk(48);
P( 49 ) = 1  + h_cytoplasm/Kh(49) + m_cytoplasm/Km(49) + k_cytoplasm/Kk(49);
P( 51 ) = 1  + h_cytoplasm/Kh(51) + m_cytoplasm/Km(51) + k_cytoplasm/Kk(51);
P( 53 ) = 1  + h_cytoplasm/Kh(53) + m_cytoplasm/Km(53) + k_cytoplasm/Kk(53);
P( 55 ) = 1  + h_cytoplasm/Kh(55) + m_cytoplasm/Km(55) + k_cytoplasm/Kk(55);
P( 29 ) = 1  + h_im/Kh(29) + m_im/Km(29) + k_im/Kk(29);
P( 30 ) = 1  + h_im/Kh(30) + m_im/Km(30) + k_im/Kk(30);
P( 31 ) = 1  + h_im/Kh(31) + m_im/Km(31) + k_im/Kk(31);
P( 32 ) = 1  + h_im/Kh(32) + m_im/Km(32) + k_im/Kk(32);
P( 33 ) = 1  + h_im/Kh(33) + m_im/Km(33) + k_im/Kk(33);
P( 34 ) = 1  + h_im/Kh(34) + m_im/Km(34) + k_im/Kk(34);
P( 35 ) = 1  + h_im/Kh(35) + m_im/Km(35) + k_im/Kk(35);
P( 36 ) = 1  + h_im/Kh(36) + m_im/Km(36) + k_im/Kk(36);
P( 37 ) = 1  + h_im/Kh(37) + m_im/Km(37) + k_im/Kk(37);
P( 38 ) = 1  + h_im/Kh(38) + m_im/Km(38) + k_im/Kk(38);
P( 40 ) = 1  + h_im/Kh(40) + m_im/Km(40) + k_im/Kk(40);
P( 41 ) = 1  + h_im/Kh(41) + m_im/Km(41) + k_im/Kk(41);
P( 50 ) = 1  + h_im/Kh(50) + m_im/Km(50) + k_im/Kk(50);
P( 52 ) = 1  + h_im/Kh(52) + m_im/Km(52) + k_im/Kk(52);
P( 54 ) = 1  + h_im/Kh(54) + m_im/Km(54) + k_im/Kk(54);

%% THERMODYNAMIC EQUATIONS
DGro_PDH =19.3245;
DGro_CTS =41.996;
DGro_ACON =6.65;
DGro_IDH =91.583;
DGro_AKGDH =12.773;
DGro_SCS =47.126;
DGro_SDH =-1.35;
DGro_FUM =-3.6;
DGro_MDH =68.943;
DGro_NDK =-4.7305e-013;
DGro_AAT =-1.47;
DGro_HK =16.994;
DGro_F1F0ATPASE =-5.643;
DGro_PYRH =0;
DGro_GLUH =0;
DGro_CITMAL =-1.1369e-013;
DGro_AKGMAL =0;
DGro_MALPI =0;
DGro_SUCMAL =-1.1369e-013;
DGro_ASPGLU =-1.1826e-013;
DGro_ETC1 =-109.493;
DGro_ETC3 =47.054;
DGro_ETC4 =-202.524;
DGro_PIH =0;
DGro_KH =0;
DGro_ANT =-4.7305e-013;
DGro_HLEAK =0;
DGro_PYRPERM =0;
DGro_CITPERM =0;
DGro_MALPERM =0;
DGro_AKGPERM =0;
DGro_SUCPERM =0;
DGro_GLUPERM =0;
DGro_ASPPERM =0;
DGro_FUMPERM =0;
DGro_ICITPERM =0;
DGro_ADPPERM =0;
DGro_ATPPERM =0;
DGro_AMPPERM =0;
DGro_PIPERM =0;

Keq_PDH_matrix = exp(-DGro_PDH/RT)/P(1)/P(2)/P(3)*P(4)*P(5)*P(6)/h_matrix;
Keq_CTS_matrix = exp(-DGro_CTS/RT)*P(2)/P(5)/P(7)*P(8)/h_matrix^2;
Keq_ACON_matrix = exp(-DGro_ACON/RT)/P(8)*P(13);
Keq_IDH_matrix = exp(-DGro_IDH/RT)/P(3)*P(4)*P(6)/P(13)*P(14)/h_matrix^2;
Keq_AKGDH_matrix = exp(-DGro_AKGDH/RT)/P(2)/P(3)*P(4)*P(6)*P(12)/P(14)/h_matrix;
Keq_SCS_matrix = exp(-DGro_SCS/RT)*P(2)/P(12)/P(15)/P(16)*P(17)*P(18)/h_matrix;
Keq_SDH_matrix = exp(-DGro_SDH/RT)/P(17)/P(19)*P(20)*P(21);
Keq_FUM_matrix = exp(-DGro_FUM/RT)/P(21)*P(22);
Keq_MDH_matrix = exp(-DGro_MDH/RT)/P(3)*P(6)*P(7)/P(22)/h_matrix;
Keq_NDK_matrix = exp(-DGro_NDK/RT)*P(9)/P(10)*P(15)/P(18);
Keq_AAT_matrix = exp(-DGro_AAT/RT)*P(7)/P(14)/P(23)*P(24);
Keq_HK_cytoplasm = exp(-DGro_HK/RT)/P(25)/P(26)*P(27)*P(28)/h_cytoplasm;
Keq_F1F0ATPASE = exp(-DGro_F1F0ATPASE/RT)* exp( +(3*F*DPsi_im_to_matrix)/RT)*P(9)/P(10)/P(16)*h_im^3/h_matrix^2;
Keq_PYRH = exp(-DGro_PYRH/RT)*P(1)/P(29)*h_im^1/h_matrix^1;
Keq_GLUH = exp(-DGro_GLUH/RT)*P(24)/P(30)*h_im^1/h_matrix^1;
Keq_CITMAL = exp(-DGro_CITMAL/RT)*P(8)/P(22)/P(31)*P(32);
Keq_AKGMAL = exp(-DGro_AKGMAL/RT)*P(14)/P(22)*P(32)/P(33);
Keq_MALPI = exp(-DGro_MALPI/RT)/P(16)*P(22)/P(32)*P(34);
Keq_SUCMAL = exp(-DGro_SUCMAL/RT)*P(17)/P(22)*P(32)/P(35);
Keq_ASPGLU = exp(-DGro_ASPGLU/RT)* exp( -(1*F*DPsi_im_to_matrix)/RT)*P(23)/P(24)*P(30)/P(36);
Keq_ETC1 = exp(-DGro_ETC1/RT)* exp( -(4*F*DPsi_im_to_matrix)/RT)*P(3)/P(6)/P(19)*P(20)*h_matrix^5/h_im^4;
Keq_ETC3 = exp(-DGro_ETC3/RT)* exp( -(2*F*DPsi_im_to_matrix)/RT)*P(19)/P(20)/P(37)^2*P(38)^2*h_matrix^2/h_im^4;
Keq_ETC4 = exp(-DGro_ETC4/RT)* exp( -(4*F*DPsi_im_to_matrix)/RT)*P(37)^2/P(38)^2/P(39)^0.5*h_matrix^4/h_im^2;
Keq_PIH = exp(-DGro_PIH/RT)*P(16)/P(34)*h_im^2/h_matrix^2;
Keq_KH = exp(-DGro_KH/RT)*k_im^1*h_matrix^1/k_matrix^1/h_im^1;
Keq_ANT = exp(-DGro_ANT/RT)* exp( +(1*F*DPsi_im_to_matrix)/RT)/P(9)*P(10)/P(40)*P(41);
Keq_HLEAK = exp(-DGro_HLEAK/RT)* exp( +(1*F*DPsi_im_to_matrix)/RT)*h_im^1/h_matrix^1;
Keq_PYRPERM = exp(-DGro_PYRPERM/RT)*P(29)/P(42);
Keq_CITPERM = exp(-DGro_CITPERM/RT)*P(31)/P(43);
Keq_MALPERM = exp(-DGro_MALPERM/RT)*P(32)/P(44);
Keq_AKGPERM = exp(-DGro_AKGPERM/RT)*P(33)/P(45);
Keq_SUCPERM = exp(-DGro_SUCPERM/RT)*P(35)/P(46);
Keq_GLUPERM = exp(-DGro_GLUPERM/RT)*P(30)/P(47);
Keq_ASPPERM = exp(-DGro_ASPPERM/RT)*P(36)/P(48);
Keq_FUMPERM = exp(-DGro_FUMPERM/RT)/P(49)*P(50);
Keq_ICITPERM = exp(-DGro_ICITPERM/RT)/P(51)*P(52);
Keq_ADPPERM = exp(-DGro_ADPPERM/RT)/P(27)*P(40);
Keq_ATPPERM = exp(-DGro_ATPPERM/RT)/P(26)*P(41);
Keq_AMPPERM = exp(-DGro_AMPPERM/RT)/P(53)*P(54);
Keq_PIPERM = exp(-DGro_PIPERM/RT)*P(34)/P(55);

%% FLUX EQUATIONS
%PDH_matrix
a=pyruvate_matrix;
b=COAS_matrix;
c=NAD_matrix;
p=CO2tot_matrix;
q=acetylcoA_matrix;
r=NADH_matrix;
%KmandKivalues[M]
KmA=38.3e-6;
KmB=9.9e-6;
KmC=60.7e-6;
KiACCOA=40.2e-6;
KiNADH=40.0e-6;
Vmf_PDH=par(1);
%Inhibitionconstants
ai1=1+acetylcoA_matrix/KiACCOA;
ai2=1+NADH_matrix/KiNADH;
if(a>MinCon)&&(b>MinCon)&&(c>MinCon)
J_PDH_matrix=Vmf_PDH*(a*b*c-p*q*r/Keq_PDH_matrix)/(KmC*ai2*a*b+KmB*ai1*a*c+KmA*b*c+a*b*c);
else
J_PDH_matrix=0;
end
%CTS_matrix
a=oxaloacetate_matrix;
b=acetylcoA_matrix;
p=COAS_matrix;
q=citrate_matrix;
%KmandKi[M]
KmA=4e-6;
KmB=14e-6;
Kia=3.33e-6;
KiCIT=1600e-6;
KiATP=900e-6;
KiADP=1800e-6;
KiAMP=6000e-6;
KiCOASH=67e-6;
KiSCOA=140e-6;
%Unchelatedcitrate,atp,adpandamp
uCIT=citrate_matrix*(1+h_matrix/Kh(8))/P(8);
uATP=ATP_matrix*(1+h_matrix/Kh(9))/P(9);
uADP=ADP_matrix*(1+h_matrix/Kh(10))/P(10);
uAMP=AMP_matrix*(1+h_matrix/Kh(11))/P(11);
ai1=1+uCIT/KiCIT;
ai2=1+uATP/KiATP+uADP/KiADP+uAMP/KiAMP+COAS_matrix/KiCOASH+succinylcoA_matrix/KiSCOA;
Vmf_CTS=par(2);
%Forwardflux
J_cits_f=Vmf_CTS*a*b/(Kia*KmB*ai1+KmA*ai1*b+KmB*ai2*a+a*b);
%Reverseflux
J_CTS_matrix=J_cits_f-Vmf_CTS*(p*q/Keq_CTS_matrix)/(Kia*KmB*ai1+KmA*ai1*b+KmB*ai2*a+a*b);
%ACON_matrix
a=citrate_matrix;
p=isocitrate_matrix;
KmA=1161e-6;
KmP=434e-6;
Vmf_ACON=par(3);
Vmr=Vmf_ACON*(KmP/KmA/Keq_ACON_matrix);
J_f=Vmf_ACON*Vmr*a/(KmA*Vmr+Vmr*a+Vmf_ACON/Keq_ACON_matrix*p);
J_ACON_matrix=J_f-Vmf_ACON*Vmr*(p/Keq_ACON_matrix)/(KmA*Vmr+Vmr*a+Vmf_ACON/Keq_ACON_matrix*p);
%IDH_matrix
a=NAD_matrix;
b=isocitrate_matrix;
p=ketoglutarate_matrix;
q=NADH_matrix;
r=CO2tot_matrix;
KmA=74e-6;
KmB=183e-6;
n=3.0;
Kib=23.8e-6;
Kiq=29e-6;
KiATP=91e-6;
KaADP=50e-6;
fATP=ATP_matrix*(1+h_matrix/Kh(9))/P(9);
fADP=ADP_matrix*(1+h_matrix/Kh(10))/P(10);
ai=1+KaADP/fADP*(1+fATP/KiATP);
Vmf_IDH=par(4);
if(a>MinCon)&&(b>MinCon)
J_IDH_matrix=Vmf_IDH/(1+(KmB/b)^n*ai+KmA/a*(1+(Kib/b)^n*ai+q*ai/Kiq))*(1-1/Keq_IDH_matrix*p*q*r/a/b);
else
J_IDH_matrix=0;
end
%AKGDH_matrix
a=ketoglutarate_matrix;
b=COAS_matrix;
c=NAD_matrix;
p=CO2tot_matrix;
q=succinylcoA_matrix;
r=NADH_matrix;
KmA=80e-6;
KmB=55e-6;
KmC=21e-6;
Kiq=6.9e-6;
Kir2=12.7e-6;
KiATP=50e-6;
KaADP=100e-6;
fATP=ATP_matrix*(1+h_matrix/Kh(9))/P(9);
fADP=ADP_matrix*(1+h_matrix/Kh(10))/P(10);
ai=1+KaADP/fADP*(1+fATP/KiATP);
Vmf_AKGDH=par(5);
Kir1=par(6);
Kir2=1e3;
if(a>MinCon)&&(b>MinCon)&&(c>MinCon)
J_AKGDH_matrix=Vmf_AKGDH/(1+KmA/a*ai+KmB/b*(1+q/Kiq)+KmC/c*(1+r/Kir1))/(1+r/Kir2)*(1-1/Keq_AKGDH_matrix*p*q*r/(a*b*c));
else
J_AKGDH_matrix=0;
end
%SCS_matrix
a=GDP_matrix;
b=succinylcoA_matrix;
c=Pi_matrix;
p=COAS_matrix;
q=succinate_matrix;
r=GTP_matrix;
KmA=16e-6;
KmB=55e-6;
KmC=660e-6;
KmP=20e-6;
KmQ=880e-6;
KmR=11.1e-6;
Kia=5.5e-6;
Kib=100e-6;
Kic=2000e-6;
Kip=20e-6;
Kiq=3000e-6;
Kir=11.1e-6;
Vmf_SCS=par(7);
Vmr=Vmf_SCS/Keq_SCS_matrix*KmP*Kiq*Kir/(Kia*Kib*KmC);
J_SCS_matrix=(Vmf_SCS*Vmr*a*b*c-Vmf_SCS*Vmr*(p*q*r/Keq_SCS_matrix))...
/(Vmr*Kia*Kib*KmC+Vmr*Kib*KmC*a+Vmr*Kia*KmB*c...
+Vmr*KmC*a*b+Vmr*KmB*a*c+Vmr*KmA*b*c+Vmr*a*b*c...
+Vmf_SCS*Kir*KmQ*p/Keq_SCS_matrix+Vmf_SCS*Kiq*KmP*r/Keq_SCS_matrix...
+Vmf_SCS*KmR*p*q/Keq_SCS_matrix+Vmf_SCS*KmQ*p*r/Keq_SCS_matrix...
+Vmf_SCS*KmP*q*r/Keq_SCS_matrix+Vmf_SCS*p*q*r/Keq_SCS_matrix...
+Vmf_SCS*KmQ*Kir*a*p/Kia/Keq_SCS_matrix+Vmr*Kia*KmB*c*r/Kir...
+Vmf_SCS*KmQ*Kir*a*b*p/Kia/Kib/Keq_SCS_matrix+Vmr*KmA*b*c*r/Kir...
+Vmf_SCS*KmR*a*p*q/Kia/Keq_SCS_matrix+Vmr*Kia*KmB*c*q*r/Kiq/Kir...
+Vmf_SCS*Kir*KmQ*a*b*c*p/Kia/Kib/Kic/Keq_SCS_matrix...
+Vmf_SCS*Kip*KmR*a*b*c*q/Kia/Kib/Kic/Keq_SCS_matrix...
+Vmf_SCS*KmR*a*b*p*q/Kia/Kib/Keq_SCS_matrix...
+Vmr*KmA*b*c*q*r/Kiq/Kir...
+Vmr*KmA*Kic*b*p*q*r/Kip/Kiq/Kir...
+Vmr*Kia*KmB*c*p*q*r/Kip/Kiq/Kir...
+Vmf_SCS*KmR*a*b*c*p*q/Kia/Kib/Kic/Keq_SCS_matrix...
+Vmr*KmA*b*c*p*q*r/Kip/Kiq/Kir);
%SDH_matrix
a=succinate_matrix;
b=coQ_matrix;
p=coQH2_matrix;
q=fumarate_matrix;
KmA=467e-6;
KmB=480e-6;
KmP=2.45e-6;
KmQ=1200e-6;
Kia=120e-6;
Kiq=1275e-6;
KiOAA=1.5e-6;
KaSUC=450e-6;
KaFUM=375e-6;
Vmf_SDH=par(8);
Vmr=(Vmf_SDH*KmP*Kiq)/(Keq_SDH_matrix*Kia*KmB);
alpha=(1+oxaloacetate_matrix/KiOAA+a/KaSUC+q/KaFUM)/(1+a/KaSUC+q/KaFUM);
denom=Vmr*Kia*KmB*alpha+Vmr*KmB*a+Vmr*KmA*alpha*b+(Vmf_SDH*KmQ*alpha/Keq_SDH_matrix)*p...
+(Vmf_SDH*KmP/Keq_SDH_matrix)*q+Vmr*a*b+(Vmf_SDH*KmQ)/(Keq_SDH_matrix*Kia)*a*p+(Vmr*KmA/Kiq)*b*q...
+(Vmf_SDH/Keq_SDH_matrix)*p*q;
J_SDH_matrix=(Vmf_SDH*Vmr*(a*b-p*q/Keq_SDH_matrix))/denom;
%FUM_matrix
a=fumarate_matrix;
p=malate_matrix;
KmA=44.7e-6;
KmP=197.7e-6;
KiCIT=3500e-6;
KiATP=40e-6;
KiADP=400e-6;
KiGTP=80e-6;
KiGDP=330e-6;
fATP=ATP_matrix*(1+h_matrix/Kh(9))/P(9);
fADP=ADP_matrix*(1+h_matrix/Kh(10))/P(10);
fGTP=GTP_matrix*(1+h_matrix/Kh(18))/P(18);
fGDP=GDP_matrix*(1+h_matrix/Kh(15))/P(15);
ai=1+citrate_matrix/KiCIT+fATP/KiATP+fADP/KiADP+fGTP/KiGTP+fGDP/KiGDP;
Vmf_FUM=par(9);
Vmr=Vmf_FUM/Keq_FUM_matrix*(KmP/KmA);
J_FUM_matrix=(Vmf_FUM*Vmr*a-Vmf_FUM*Vmr*(p/Keq_FUM_matrix))/(KmA*Vmr*ai+Vmr*a+Vmf_FUM/Keq_FUM_matrix*p);
%MDH_matrix
a=NAD_matrix;
b=malate_matrix;
p=oxaloacetate_matrix;
q=NADH_matrix;
KmA=90.55e-6;
KmB=250e-6;
KmP=6.128e-6;
KmQ=2.58e-6;
Kia=279e-6;
Kib=360e-6;
Kip=5.5e-6;
Kiq=3.18e-6;
KiATP=183.2e-6;
KiADP=394.4e-6;
KiAMP=420.0e-6;
fATP=ATP_matrix*(1+h_matrix/Kh(9))/P(9);
fADP=ADP_matrix*(1+h_matrix/Kh(10))/P(10);
fAMP=AMP_matrix*(1+h_matrix/Kh(11))/P(11);
ai=1+fATP/KiATP+fADP/KiADP+fAMP/KiAMP;
Vmf_MDH=par(10);
Vmr=Vmf_MDH/Keq_MDH_matrix*(Kiq*KmP/Kia/KmB);
J_MDH_matrix=(Vmf_MDH*Vmr*a*b-Vmf_MDH*Vmr*(p*q/Keq_MDH_matrix))/(Vmr*Kia*KmB*ai+Vmr*KmB*a+Vmr*KmA*ai*b+Vmf_MDH*KmQ*ai/Keq_MDH_matrix*p+Vmf_MDH*KmP/Keq_MDH_matrix*q+Vmr*a*b+Vmf_MDH*KmQ/Kia/Keq_MDH_matrix*a*p+Vmf_MDH/Keq_MDH_matrix*p*q+Vmr*KmA/Kiq*b*q+Vmr/Kip*a*b*p+Vmf_MDH/Kib/Keq_MDH_matrix*b*p*q);
%NDK_matrix
a=GTP_matrix;
b=ADP_matrix;
p=GDP_matrix;
q=ATP_matrix;
KmA=111e-6;
KmB=100e-6;
KmP=260e-6;
KmQ=278e-6;
Kia=170e-6;
Kib=143.6e-6;
Kip=146.6e-6;
Kiq=156.5e-6;
KiAMP=650e-6;
fAMP=AMP_matrix*(1+h_matrix/Kh(11))/P(11);
ai=1+fAMP/KiAMP;
Vmf_NDK=par(11);
Vmr=Vmf_NDK/Keq_NDK_matrix*(KmQ*Kip/Kia/KmB);
if(a>MinCon)&&(b>MinCon)
ab=a*b;
else
ab=0;
end
if(p>MinCon)&&(q>MinCon)
pq=p*q;
else
pq=0;
end
J_NDK_matrix=Vmf_NDK*Vmr*(ab-pq/Keq_NDK_matrix)/ai/(Vmr*KmB*a+Vmr*KmA*b+Vmf_NDK*KmQ/Keq_NDK_matrix*p+Vmf_NDK*KmP/Keq_NDK_matrix*q+Vmr*a*b+Vmf_NDK*KmQ/Kia/Keq_NDK_matrix*a*p+Vmf_NDK/Keq_NDK_matrix*p*q+Vmr*KmA/Kiq*b*q);
%AAT_matrix
a=aspartate_matrix;
b=ketoglutarate_matrix;
p=oxaloacetate_matrix;
q=glutamate_matrix;
KmA=3900e-6;
KmB=430e-6;
KmP=88e-6;
KmQ=8900e-6;
Kia=3480e-6;
Kib=710e-6;
Kip=50e-6;
Kiq=8400e-6;
KiAKG=16.6e-3;
ai=1+b/KiAKG;
Vmf_GOT=par(12);
Vmr=Vmf_GOT/Keq_AAT_matrix*(KmQ*Kip/Kia/KmB);
if(a>MinCon)&&(b>MinCon)
ab=a*b;
else
ab=0;
end
if(p>MinCon)&&(q>MinCon)
pq=p*q;
else
pq=0;
end
J_AAT_matrix=Vmf_GOT*Vmr*(ab-pq/Keq_AAT_matrix)/(Vmr*KmB*a+Vmr*KmA*ai*b+Vmf_GOT*KmQ/Keq_AAT_matrix*ai*p+Vmf_GOT*KmP/Keq_AAT_matrix*q+Vmr*a*b+Vmf_GOT*KmQ/Kia/Keq_AAT_matrix*a*p+Vmf_GOT/Keq_AAT_matrix*p*q+Vmr*KmA/Kiq*b*q);
%HK_cytoplasm
a=ATP_cytoplasm*(m_cytoplasm/Km(26))/P(26);
b=glucose_cytoplasm;
p=glucose6phos_cytoplasm;
q=ADP_cytoplasm*(m_cytoplasm/Km(27))/P(27);
KmA=1e-3;
Kia=1e-3;
KmB=47e-6;
Kib=47e-6;
KmP=47e-6;
Kip=47e-6;
KmQ=1e-3;
Kiq=1e-3;
KiG6P=10e-6;
x_HK=par(13);
Kapp_HK_m=Keq_HK_cytoplasm*(Km(26)*P(26))/(Km(27)*P(27));
J_HK_cytoplasm=x_HK/(Kib*KmA)*(a*b-p*q/Kapp_HK_m)/(1+a/Kia+b/Kib+a*b/Kib/KmA+p/Kip+q/Kiq+p*q/Kiq/KmP+p*b/KiG6P/Kib)*(1+VWater_cytoplasm);
%F1F0ATPASE:im_to_matrix
k1_F1F0 =par(14);
J_F1F0ATPASE_im_to_matrix = k1_F1F0*(Keq_F1F0ATPASE*ADP_matrix*Pi_matrix-ATP_matrix);
%PYRH:im_to_matrix
x_PYRH =par(15);
pyruvate1 = pyruvate_matrix/P(1);
pyruvate2 = pyruvate_im/P(29);
J_PYRH_im_to_matrix = x_PYRH* (pyruvate2*h_im - pyruvate1*h_matrix);
%GLUH:im_to_matrix
x_GLUH =par(16);
glutamate1 = glutamate_matrix/P(24);
glutamate2 = glutamate_im/P(30);
J_GLUH_im_to_matrix = x_GLUH * (glutamate2*h_im - glutamate1*h_matrix);
%CITMAL:im_to_matrix
x_CITMAL =par(17);
Kh_iCIT = 10^(-5.63);
citrate1 = citrate_matrix*(h_matrix/Kh_iCIT)/P(8);
citrate2 = citrate_im*(h_im/Kh_iCIT)/P(31);
malate1 = malate_matrix/P(22);
malate2 = malate_im/P(32);
J_CITMAL_im_to_matrix = x_CITMAL * (citrate2*malate1 - citrate1*malate2);
%AKGMAL:im_to_matrix
akg1 = ketoglutarate_matrix;
akg2 = ketoglutarate_im;
mal1 = malate_matrix;
mal2 = malate_im;
KmMALi = 1.4e-3;
KmMALx = 0.7e-3;
KmAKGi = 0.3e-3;
KmAKGx = 0.17e-3;
x_AKGMAL =par(18);
J_AKGMAL_im_to_matrix = x_AKGMAL /(KmMALx*KmAKGi)*(mal1*akg2-mal2*akg1)/(2 + mal2/KmMALi + mal1/KmMALx + akg2/KmAKGi + akg1/KmAKGx +mal2*akg1/(KmMALi*KmAKGx) + mal1*akg2/(KmMALx*KmAKGi));
%MALPI:im_to_matrix
x_MALPI =par(19);
malate1 = malate_matrix/P(22);
malate2 = malate_im/P(32);
pi1 = Pi_matrix/P(16);
pi2 = Pi_im/P(34);
J_MALPI_im_to_matrix = x_MALPI * (malate2*pi1 - malate1*pi2);
%SUCMAL:im_to_matrix
x_SUCMAL =par(20);
succinate1 = succinate_matrix/P(17);
succinate2 = succinate_im/P(35);
malate1 = malate_matrix/P(22);
malate2 = malate_im/P(32);
J_SUCMAL_im_to_matrix = x_SUCMAL * (succinate2*malate1-succinate1*malate2);
%ASPGLU:im_to_matrix
Kiaspi = 28e-6;
Kiaspx = 2.8e-3;
Kiglui = 180e-6;
Kiglux = 1.6e-3;
pKa_gaa = 6.5;
Kh_gaa = 10^(-pKa_gaa);
x_ASPGLU =par(21);
glu1 = glutamate_matrix;
%/ P(24);
glu2 = glutamate_im;
%/ P(30);
asp1 = aspartate_matrix;
%/ P(23);
asp2 = aspartate_im;
%/ P(36);
h1 = h_matrix;
h2 = h_im;
m=1.8;
J_ASPGLU_im_to_matrix = x_ASPGLU / (Keq_ASPGLU*Kiaspi*Kiglux*Kh_gaa)*(Keq_ASPGLU*asp2*glu1*h1 - asp1*glu2*h2)/ (2*m + m*asp2/Kiaspi + asp2*glu1*h1/(Kiaspi*Kiglux*Kh_gaa) + m*asp1*h2/(Kiaspx*Kh_gaa) + asp1*glu2*h2/(Kiaspx*Kiglui*Kh_gaa) + m*asp1/Kiaspx + m*asp2*h1/(Kiaspi*Kh_gaa) + m*h1/Kh_gaa + m*glu2*h2/(Kiglui*Kh_gaa) + m*h2/Kh_gaa + m*glu1*h1/(Kiglux*Kh_gaa));
%ETC1:im_to_matrix
ETC1Activity =par(22);
NADH1 = NADH_matrix/P(6);
NAD1 = NAD_matrix/P(3);
coQ1 = coQ_matrix/P(19);
QH21 = coQH2_matrix/P(20);
J_ETC1_im_to_matrix = ETC1Activity * ( Keq_ETC1 * NADH1 * coQ1 - NAD1 * QH21 );
%ETC3:im_to_matrix
ETC3_activity =par(23);
k_Pi1 =par(24);
k_Pi2 =par(25);
a = max(MinCon,coQH2_matrix);
b = max(MinCon,coQ_matrix);
J_ETC3_im_to_matrix = ETC3_activity*((1+Pi_matrix/k_Pi1)/(1+Pi_matrix/k_Pi2))*(Keq_ETC3^0.5*cytocox_im*sqrt(a) - cytocred_im*sqrt(b) );
%ETC4:im_to_matrix
ETC4_activity =par(26);
k_O2 = 1.2e-4;
Ctot = 2.70e-3;
J_ETC4_im_to_matrix = ETC4_activity*(O2aq_matrix/(O2aq_matrix+k_O2))*exp(F*DPsi_im_to_matrix/RT)*(cytocred_im/Ctot)*( Keq_ETC4^0.5*cytocred_im*(O2aq_matrix^0.25) - cytocox_im );
%PIH:im_to_matrix
a = Pi_im*(h_im/Kh(34))/P(34);
p = Pi_matrix*(h_matrix/Kh(16))/P(16);
x_PIH =par(27);
k_PIH =par(28);
J_PIH_im_to_matrix = x_PIH/k_PIH*(h_im*a - h_matrix*p)/(1+a/k_PIH)/(1+p/k_PIH);
%KH:im_to_matrix
k1_KH =par(29);
J_KH_im_to_matrix = k1_KH*(k_im*h_matrix - k_matrix*h_im);
%ANT:im_to_matrix
ADP_i1 = ADP_im/P(40);
% ADP^3-
ATP_i1 = ATP_im/P(41);
% ATP^4-
ADP_x1 = ADP_matrix/P(10);
% ADP^3-
ATP_x1 = ATP_matrix/P(9);
% ATP^4-
x_ANT =par(30);
theta = 0.60;
Psi_i = theta*DPsi_im_to_matrix;
Psi_x = (theta-1)*DPsi_im_to_matrix;
k_mADP = 3.5e-6;
if (ADP_im > 1e-9) && (ATP_matrix > 1e-9)
J_ANT_im_to_matrix = x_ANT*( ADP_i1/(ADP_i1+ATP_i1*exp(-F*Psi_i/RT)) - ADP_x1/(ADP_x1+ATP_x1*exp(-F*Psi_x/RT)) )*(ADP_i1/(ADP_i1+k_mADP));
else
J_ANT_im_to_matrix = 0;
end
%HLEAK:im_to_matrix
x_HLE =par(31);
if (abs(DPsi_im_to_matrix) > 1e-9)
J_HLEAK_im_to_matrix = x_HLE*DPsi_im_to_matrix*(h_im*exp(F*DPsi_im_to_matrix/RT)-h_matrix)/(exp(F*DPsi_im_to_matrix/RT)-1);
else
J_HLEAK_im_to_matrix = x_HLE*RT*( h_im - h_matrix )/F;
end
%PYRPERM:cytoplasm_to_im
x_PYRPERM =par(32);
J_PYRPERM_cytoplasm_to_im = gamma * x_PYRPERM * (pyruvate_cytoplasm - pyruvate_im);
%CITPERM:cytoplasm_to_im
x_CITPERM =par(33);
J_CITPERM_cytoplasm_to_im = gamma * x_CITPERM * (citrate_cytoplasm - citrate_im);
%MALPERM:cytoplasm_to_im
x_MALPERM =par(34);
J_MALPERM_cytoplasm_to_im = gamma * x_MALPERM * (malate_cytoplasm - malate_im);
%AKGPERM:cytoplasm_to_im
x_AKGPERM =par(35);
J_AKGPERM_cytoplasm_to_im = gamma * x_AKGPERM * (ketoglutarate_cytoplasm - ketoglutarate_im);
%SUCPERM:cytoplasm_to_im
x_SUCPERM =par(36);
J_SUCPERM_cytoplasm_to_im = gamma * x_SUCPERM * (succinate_cytoplasm - succinate_im);
%GLUPERM:cytoplasm_to_im
x_GLUPERM =par(37);
J_GLUPERM_cytoplasm_to_im = gamma * x_GLUPERM * (glutamate_cytoplasm - glutamate_im);
%ASPPERM:cytoplasm_to_im
x_ASPPERM =par(38);
J_ASPPERM_cytoplasm_to_im = gamma * x_ASPPERM * (aspartate_cytoplasm - aspartate_im);
%FUMPERM:cytoplasm_to_im
x_FUMPERM =par(39);
J_FUMPERM_cytoplasm_to_im = gamma * x_FUMPERM * (fumarate_cytoplasm - fumarate_im);
%ICITPERM:cytoplasm_to_im
x_ICITPERM =par(40);
J_ICITPERM_cytoplasm_to_im = gamma * x_ICITPERM * (isocitrate_cytoplasm - isocitrate_im);
%ADPPERM:cytoplasm_to_im
x_ADPPERM =par(41);
J_ADPPERM_cytoplasm_to_im = gamma * x_ADPPERM * (ADP_cytoplasm - ADP_im);
%ATPPERM:cytoplasm_to_im
x_ATPPERM =par(42);
J_ATPPERM_cytoplasm_to_im = gamma * x_ATPPERM * (ATP_cytoplasm - ATP_im);
%AMPPERM:cytoplasm_to_im
x_AMPPERM =par(43);
J_AMPPERM_cytoplasm_to_im = gamma * x_AMPPERM * (AMP_cytoplasm - AMP_im);
%PIPERM:cytoplasm_to_im
x_PIPERM =par(44);
J_PIPERM_cytoplasm_to_im = gamma * x_PIPERM * (Pi_cytoplasm - Pi_im);

%% REACTANT TIME DERIVATIVES
f(1,:) = ( 0  - 1*J_PDH_matrix + 1*J_PYRH_im_to_matrix ) / VWater_matrix; % pyruvate_matrix
f(2,:) = ( 0  - 1*J_PDH_matrix + 1*J_CTS_matrix - 1*J_AKGDH_matrix + 1*J_SCS_matrix ) / VWater_matrix; % COAS_matrix
f(3,:) = ( 0  - 1*J_PDH_matrix - 1*J_IDH_matrix - 1*J_AKGDH_matrix - 1*J_MDH_matrix + 1*J_ETC1_im_to_matrix ) / VWater_matrix; % NAD_matrix
f(4,:) = ( 0  ); % [clamped] % CO2tot_matrix
f(5,:) = ( 0  + 1*J_PDH_matrix - 1*J_CTS_matrix ) / VWater_matrix; % acetylcoA_matrix
f(6,:) = ( 0  + 1*J_PDH_matrix + 1*J_IDH_matrix + 1*J_AKGDH_matrix + 1*J_MDH_matrix - 1*J_ETC1_im_to_matrix ) / VWater_matrix; % NADH_matrix
f(7,:) = ( 0  - 1*J_CTS_matrix + 1*J_MDH_matrix + 1*J_AAT_matrix ) / VWater_matrix; % oxaloacetate_matrix
f(8,:) = ( 0  + 1*J_CTS_matrix - 1*J_ACON_matrix + 1*J_CITMAL_im_to_matrix ) / VWater_matrix; % citrate_matrix
f(9,:) = ( 0  + 1*J_NDK_matrix + 1*J_F1F0ATPASE_im_to_matrix - 1*J_ANT_im_to_matrix ) / VWater_matrix; % ATP_matrix
f(10,:) = ( 0  - 1*J_NDK_matrix - 1*J_F1F0ATPASE_im_to_matrix + 1*J_ANT_im_to_matrix ) / VWater_matrix; % ADP_matrix
f(11,:) = ( 0  ) / VWater_matrix; % AMP_matrix
f(12,:) = ( 0  + 1*J_AKGDH_matrix - 1*J_SCS_matrix ) / VWater_matrix; % succinylcoA_matrix
f(13,:) = ( 0  + 1*J_ACON_matrix - 1*J_IDH_matrix ) / VWater_matrix; % isocitrate_matrix
f(14,:) = ( 0  + 1*J_IDH_matrix - 1*J_AKGDH_matrix - 1*J_AAT_matrix + 1*J_AKGMAL_im_to_matrix ) / VWater_matrix; % ketoglutarate_matrix
f(15,:) = ( 0  - 1*J_SCS_matrix + 1*J_NDK_matrix ) / VWater_matrix; % GDP_matrix
f(16,:) = ( 0  - 1*J_SCS_matrix - 1*J_F1F0ATPASE_im_to_matrix - 1*J_MALPI_im_to_matrix + 1*J_PIH_im_to_matrix ) / VWater_matrix; % Pi_matrix
f(17,:) = ( 0  + 1*J_SCS_matrix - 1*J_SDH_matrix + 1*J_SUCMAL_im_to_matrix ) / VWater_matrix; % succinate_matrix
f(18,:) = ( 0  + 1*J_SCS_matrix - 1*J_NDK_matrix ) / VWater_matrix; % GTP_matrix
f(19,:) = ( 0  - 1*J_SDH_matrix - 1*J_ETC1_im_to_matrix + 1*J_ETC3_im_to_matrix ) / VWater_matrix; % coQ_matrix
f(20,:) = ( 0  + 1*J_SDH_matrix + 1*J_ETC1_im_to_matrix - 1*J_ETC3_im_to_matrix ) / VWater_matrix; % coQH2_matrix
f(21,:) = ( 0  + 1*J_SDH_matrix - 1*J_FUM_matrix ) / VWater_matrix; % fumarate_matrix
f(22,:) = ( 0  + 1*J_FUM_matrix - 1*J_MDH_matrix - 1*J_CITMAL_im_to_matrix - 1*J_AKGMAL_im_to_matrix + 1*J_MALPI_im_to_matrix - 1*J_SUCMAL_im_to_matrix ) / VWater_matrix; % malate_matrix
f(23,:) = ( 0  - 1*J_AAT_matrix + 1*J_ASPGLU_im_to_matrix ) / VWater_matrix; % aspartate_matrix
f(24,:) = ( 0  + 1*J_AAT_matrix + 1*J_GLUH_im_to_matrix - 1*J_ASPGLU_im_to_matrix ) / VWater_matrix; % glutamate_matrix
f(39,:) = ( 0  ); % [clamped] % O2aq_matrix
f(25,:) = ( 0  - 1*J_HK_cytoplasm ) / VWater_cytoplasm; % glucose_cytoplasm
f(26,:) = ( 0  - 1*J_HK_cytoplasm - 1*J_ATPPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % ATP_cytoplasm
f(27,:) = ( 0  + 1*J_HK_cytoplasm - 1*J_ADPPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % ADP_cytoplasm
f(28,:) = ( 0  + 1*J_HK_cytoplasm ) / VWater_cytoplasm; % glucose6phos_cytoplasm
f(42,:) = ( 0  - 1*J_PYRPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % pyruvate_cytoplasm
f(43,:) = ( 0  - 1*J_CITPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % citrate_cytoplasm
f(44,:) = ( 0  - 1*J_MALPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % malate_cytoplasm
f(45,:) = ( 0  - 1*J_AKGPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % ketoglutarate_cytoplasm
f(46,:) = ( 0  - 1*J_SUCPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % succinate_cytoplasm
f(47,:) = ( 0  - 1*J_GLUPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % glutamate_cytoplasm
f(48,:) = ( 0  - 1*J_ASPPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % aspartate_cytoplasm
f(49,:) = ( 0  - 1*J_FUMPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % fumarate_cytoplasm
f(51,:) = ( 0  - 1*J_ICITPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % isocitrate_cytoplasm
f(53,:) = ( 0  - 1*J_AMPPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % AMP_cytoplasm
f(55,:) = ( 0  - 1*J_PIPERM_cytoplasm_to_im/VRegion_cytoplasm*VRegion_im ) / VWater_cytoplasm; % Pi_cytoplasm
f(29,:) = ( 0  - 1*J_PYRH_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_PYRPERM_cytoplasm_to_im ) / VWater_im; % pyruvate_im
f(30,:) = ( 0  - 1*J_GLUH_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_ASPGLU_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_GLUPERM_cytoplasm_to_im ) / VWater_im; % glutamate_im
f(31,:) = ( 0  - 1*J_CITMAL_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_CITPERM_cytoplasm_to_im ) / VWater_im; % citrate_im
f(32,:) = ( 0  + 1*J_CITMAL_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_AKGMAL_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_MALPI_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_SUCMAL_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_MALPERM_cytoplasm_to_im ) / VWater_im; % malate_im
f(33,:) = ( 0  - 1*J_AKGMAL_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_AKGPERM_cytoplasm_to_im ) / VWater_im; % ketoglutarate_im
f(34,:) = ( 0  + 1*J_MALPI_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_PIH_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_PIPERM_cytoplasm_to_im ) / VWater_im; % Pi_im
f(35,:) = ( 0  - 1*J_SUCMAL_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_SUCPERM_cytoplasm_to_im ) / VWater_im; % succinate_im
f(36,:) = ( 0  - 1*J_ASPGLU_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_ASPPERM_cytoplasm_to_im ) / VWater_im; % aspartate_im
f(37,:) = ( 0  - 2*J_ETC3_im_to_matrix/VRegion_im*VRegion_matrix + 2*J_ETC4_im_to_matrix/VRegion_im*VRegion_matrix ) / VWater_im; % cytocox_im
f(38,:) = ( 0  + 2*J_ETC3_im_to_matrix/VRegion_im*VRegion_matrix - 2*J_ETC4_im_to_matrix/VRegion_im*VRegion_matrix ) / VWater_im; % cytocred_im
f(40,:) = ( 0  - 1*J_ANT_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_ADPPERM_cytoplasm_to_im ) / VWater_im; % ADP_im
f(41,:) = ( 0  + 1*J_ANT_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_ATPPERM_cytoplasm_to_im ) / VWater_im; % ATP_im
f(50,:) = ( 0  + 1*J_FUMPERM_cytoplasm_to_im ) / VWater_im; % fumarate_im
f(52,:) = ( 0  + 1*J_ICITPERM_cytoplasm_to_im ) / VWater_im; % isocitrate_im
f(54,:) = ( 0  + 1*J_AMPPERM_cytoplasm_to_im ) / VWater_im; % AMP_im

%% ION EQUATIONS
% COMPARTMENT matrix:
ii = [1   2   3   4   5   6   7   8   9  10  11  12  13  14  15  16  17  18  19  20  21  22  23  24  39]; % Indices of SVs in compartment matrix
% PARTIAL DERIVATIVES
pHBpM = -sum( (h_matrix*x(ii)'./Kh(ii))./(Km(ii).*P(ii).^2) );
pHBpK = -sum( (h_matrix*x(ii)'./Kh(ii))./(Kk(ii).*P(ii).^2) );
pHBpH = +sum( (1+m_matrix./Km(ii)+k_matrix./Kk(ii)).*x(ii)'./(Kh(ii).*P(ii).^2) );
pMBpH = -sum( (m_matrix*x(ii)'./Km(ii))./(Kh(ii).*P(ii).^2) );
pMBpK = -sum( (m_matrix*x(ii)'./Km(ii))./(Kk(ii).*P(ii).^2) );
pMBpM = +sum( (1+h_matrix./Kh(ii)+k_matrix./Kk(ii)).*x(ii)'./(Km(ii).*P(ii).^2) );
pKBpH = -sum( (k_matrix*x(ii)'./Kk(ii))./(Kh(ii).*P(ii).^2) );
pKBpM = -sum( (k_matrix*x(ii)'./Kk(ii))./(Km(ii).*P(ii).^2) );
pKBpK = +sum( (1+h_matrix./Kh(ii)+m_matrix./Km(ii)).*x(ii)'./(Kk(ii).*P(ii).^2) );
% PHIs
J_H = (0 - 1*J_PDH_matrix + 2*J_CTS_matrix + 0*J_ACON_matrix + 0*J_IDH_matrix - 1*J_AKGDH_matrix + 1*J_SCS_matrix + 0*J_SDH_matrix + 0*J_FUM_matrix + 1*J_MDH_matrix + 0*J_NDK_matrix + 0*J_AAT_matrix + 2*J_F1F0ATPASE_im_to_matrix + 0*J_F1F0ATPASE_im_to_matrix + 1*J_PYRH_im_to_matrix + 1*J_GLUH_im_to_matrix - 5*J_ETC1_im_to_matrix - 2*J_ETC3_im_to_matrix - 4*J_ETC4_im_to_matrix + 2*J_PIH_im_to_matrix - 1*J_KH_im_to_matrix + 1*J_HLEAK_im_to_matrix + 1*J_CITMAL_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_ASPGLU_im_to_matrix/VRegion_im*VRegion_matrix) / VWater_matrix;
J_M = (0) / VWater_matrix;
J_K = (0 + 1*J_KH_im_to_matrix) / VWater_matrix;
Phi_H = J_H - sum( h_matrix*f(ii)'./(Kh(ii).*P(ii)) );
Phi_M = -sum( m_matrix*f(ii)'./(Km(ii).*P(ii)) );
Phi_K = J_K -sum( k_matrix*f(ii)'./(Kk(ii).*P(ii)) );
% ALPHAs
aH = 1 + pHBpH;
aM = 1 + pMBpM;
aK = 1 + pKBpK;
% ADDITIONAL BUFFER for [H+]
aH = 1 + pHBpH + BX(1)/K_BX(1)/(1+h_matrix/K_BX(1))^2; % M
% DENOMINATOR
D = aH*pKBpM*pMBpK + aK*pHBpM*pMBpH + aM*pHBpK*pKBpH - ...
    aM*aK*aH - pHBpK*pKBpM*pMBpH - pHBpM*pMBpK*pKBpH;
% DERIVATIVES for H,Mg,K
f(56,:) =  ( (pKBpM*pMBpK - aM*aK)*Phi_H + ...
            (aK*pHBpM - pHBpK*pKBpM)*Phi_M + ...
            (aM*pHBpK - pHBpM*pMBpK)*Phi_K ) / D;
f(57,:) =  ( (aK*pMBpH - pKBpH*pMBpK)*Phi_H + ...
            (pKBpH*pHBpK - aH*aK)*Phi_M + ...
            (aH*pMBpK - pHBpK*pMBpH)*Phi_K ) / D;
f(58,:) =  ( (aM*pKBpH - pKBpM*pMBpH)*Phi_H + ...
            (aH*pKBpM - pKBpH*pHBpM)*Phi_M + ...
            (pMBpH*pHBpM - aH*aM)*Phi_K ) / D;
% COMPARTMENT cytoplasm:
ii = [25  26  27  28  42  43  44  45  46  47  48  49  51  53  55]; % Indices of SVs in compartment cytoplasm
% PARTIAL DERIVATIVES
pHBpM = -sum( (h_cytoplasm*x(ii)'./Kh(ii))./(Km(ii).*P(ii).^2) );
pHBpK = -sum( (h_cytoplasm*x(ii)'./Kh(ii))./(Kk(ii).*P(ii).^2) );
pHBpH = +sum( (1+m_cytoplasm./Km(ii)+k_cytoplasm./Kk(ii)).*x(ii)'./(Kh(ii).*P(ii).^2) );
pMBpH = -sum( (m_cytoplasm*x(ii)'./Km(ii))./(Kh(ii).*P(ii).^2) );
pMBpK = -sum( (m_cytoplasm*x(ii)'./Km(ii))./(Kk(ii).*P(ii).^2) );
pMBpM = +sum( (1+h_cytoplasm./Kh(ii)+k_cytoplasm./Kk(ii)).*x(ii)'./(Km(ii).*P(ii).^2) );
pKBpH = -sum( (k_cytoplasm*x(ii)'./Kk(ii))./(Kh(ii).*P(ii).^2) );
pKBpM = -sum( (k_cytoplasm*x(ii)'./Kk(ii))./(Km(ii).*P(ii).^2) );
pKBpK = +sum( (1+h_cytoplasm./Kh(ii)+m_cytoplasm./Km(ii)).*x(ii)'./(Kk(ii).*P(ii).^2) );
% PHIs
J_H = (0 + 1*J_HK_cytoplasm ) / ( 0 + VWater_cytoplasm + VWater_im );
J_M = (0 ) / ( 0 + VWater_cytoplasm + VWater_im );
J_K = (0 ) / ( 0 + VWater_cytoplasm + VWater_im );
Phi_H = J_H - sum( h_cytoplasm*f(ii)'./(Kh(ii).*P(ii)) );
Phi_M = -sum( m_cytoplasm*f(ii)'./(Km(ii).*P(ii)) );
Phi_K = J_K -sum( k_cytoplasm*f(ii)'./(Kk(ii).*P(ii)) );
% ALPHAs
aH = 1 + pHBpH;
aM = 1 + pMBpM;
aK = 1 + pKBpK;
% ADDITIONAL BUFFER for [H+]
aH = 1 + pHBpH + BX(2)/K_BX(2)/(1+h_cytoplasm/K_BX(2))^2; % M
% DENOMINATOR
D = aH*pKBpM*pMBpK + aK*pHBpM*pMBpH + aM*pHBpK*pKBpH - ...
    aM*aK*aH - pHBpK*pKBpM*pMBpH - pHBpM*pMBpK*pKBpH;
% DERIVATIVES for H,Mg,K
f(59,:) =  ( (pKBpM*pMBpK - aM*aK)*Phi_H + ...
            (aK*pHBpM - pHBpK*pKBpM)*Phi_M + ...
            (aM*pHBpK - pHBpM*pMBpK)*Phi_K ) / D;
f(60,:) =  0;
f(61,:) =  0;
% COMPARTMENT im:
ii = [29  30  31  32  33  34  35  36  37  38  40  41  50  52  54]; % Indices of SVs in compartment im
% PARTIAL DERIVATIVES
pHBpM = -sum( (h_im*x(ii)'./Kh(ii))./(Km(ii).*P(ii).^2) );
pHBpK = -sum( (h_im*x(ii)'./Kh(ii))./(Kk(ii).*P(ii).^2) );
pHBpH = +sum( (1+m_im./Km(ii)+k_im./Kk(ii)).*x(ii)'./(Kh(ii).*P(ii).^2) );
pMBpH = -sum( (m_im*x(ii)'./Km(ii))./(Kh(ii).*P(ii).^2) );
pMBpK = -sum( (m_im*x(ii)'./Km(ii))./(Kk(ii).*P(ii).^2) );
pMBpM = +sum( (1+h_im./Kh(ii)+k_im./Kk(ii)).*x(ii)'./(Km(ii).*P(ii).^2) );
pKBpH = -sum( (k_im*x(ii)'./Kk(ii))./(Kh(ii).*P(ii).^2) );
pKBpM = -sum( (k_im*x(ii)'./Kk(ii))./(Km(ii).*P(ii).^2) );
pKBpK = +sum( (1+h_im./Kh(ii)+m_im./Km(ii)).*x(ii)'./(Kk(ii).*P(ii).^2) );
% PHIs
J_H = (0 - 3*J_F1F0ATPASE_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_PYRH_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_GLUH_im_to_matrix/VRegion_im*VRegion_matrix + 4*J_ETC1_im_to_matrix/VRegion_im*VRegion_matrix + 4*J_ETC3_im_to_matrix/VRegion_im*VRegion_matrix + 2*J_ETC4_im_to_matrix/VRegion_im*VRegion_matrix - 2*J_PIH_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_KH_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_HLEAK_im_to_matrix/VRegion_im*VRegion_matrix - 1*J_CITMAL_im_to_matrix/VRegion_im*VRegion_matrix + 1*J_ASPGLU_im_to_matrix/VRegion_im*VRegion_matrix ) / ( 0 + VWater_cytoplasm + VWater_im );
J_M = (0 ) / ( 0 + VWater_cytoplasm + VWater_im );
J_K = (0 - 1*J_KH_im_to_matrix/VRegion_im*VRegion_matrix ) / ( 0 + VWater_cytoplasm + VWater_im );
Phi_H = J_H - sum( h_im*f(ii)'./(Kh(ii).*P(ii)) );
Phi_M = -sum( m_im*f(ii)'./(Km(ii).*P(ii)) );
Phi_K = J_K -sum( k_im*f(ii)'./(Kk(ii).*P(ii)) );
% ALPHAs
aH = 1 + pHBpH;
aM = 1 + pMBpM;
aK = 1 + pKBpK;
% ADDITIONAL BUFFER for [H+]
aH = 1 + pHBpH + BX(3)/K_BX(3)/(1+h_im/K_BX(3))^2; % M
% DENOMINATOR
D = aH*pKBpM*pMBpK + aK*pHBpM*pMBpH + aM*pHBpK*pKBpH - ...
    aM*aK*aH - pHBpK*pKBpM*pMBpH - pHBpM*pMBpK*pKBpH;
% DERIVATIVES for H,Mg,K
f(59,:) = f(59,:) +  ( (pKBpM*pMBpK - aM*aK)*Phi_H + ...
            (aK*pHBpM - pHBpK*pKBpM)*Phi_M + ...
            (aM*pHBpK - pHBpM*pMBpK)*Phi_K ) / D;
f(60,:) = f(60,:) +  0;
f(61,:) = f(61,:) +  0;

%% ELECTROPHYS EQUATIONS
C_im_to_matrix = par(45);
f(65) = ( 0 - 3*J_F1F0ATPASE_im_to_matrix  + 1*J_ASPGLU_im_to_matrix  + 4*J_ETC1_im_to_matrix  + 2*J_ETC3_im_to_matrix  + 4*J_ETC4_im_to_matrix  - 1*J_ANT_im_to_matrix  - 1*J_HLEAK_im_to_matrix ) / C_im_to_matrix;
C_cytoplasm_to_im = par(46);
f(66) = ( 0) / C_cytoplasm_to_im;
%% FLUX VECTOR:
J = [ J_PDH_matrix J_CTS_matrix J_ACON_matrix J_IDH_matrix J_AKGDH_matrix J_SCS_matrix J_SDH_matrix J_FUM_matrix J_MDH_matrix J_NDK_matrix J_AAT_matrix J_HK_cytoplasm J_F1F0ATPASE_im_to_matrix J_PYRH_im_to_matrix J_GLUH_im_to_matrix J_CITMAL_im_to_matrix J_AKGMAL_im_to_matrix J_MALPI_im_to_matrix J_SUCMAL_im_to_matrix J_ASPGLU_im_to_matrix J_ETC1_im_to_matrix J_ETC3_im_to_matrix J_ETC4_im_to_matrix J_PIH_im_to_matrix J_KH_im_to_matrix J_ANT_im_to_matrix J_HLEAK_im_to_matrix J_PYRPERM_cytoplasm_to_im J_CITPERM_cytoplasm_to_im J_MALPERM_cytoplasm_to_im J_AKGPERM_cytoplasm_to_im J_SUCPERM_cytoplasm_to_im J_GLUPERM_cytoplasm_to_im J_ASPPERM_cytoplasm_to_im J_FUMPERM_cytoplasm_to_im J_ICITPERM_cytoplasm_to_im J_ADPPERM_cytoplasm_to_im J_ATPPERM_cytoplasm_to_im J_AMPPERM_cytoplasm_to_im J_PIPERM_cytoplasm_to_im];
